@@ -82,15 +82,22 @@ public:
     bool isEnableExtMonLidClosedActions();
     void setEnableExtMonLidClosedActions(bool enableExtMonLidClosedActions);
 
-    int getIdlenessAction();
-    void setIdlenessAction(int idlenessAction);
-
-    int getIdlenessTimeSecs();
-    void setIdlenessTimeSecs(int idlenessTimeSecs);
 
     bool isIdlenessWatcherEnabled();
     void setIdlenessWatcherEnabled(bool idlenessWatcherEnabled);
 
+    int getIdlenessACAction();
+    void setIdlenessACAction(int idlenessAction);
+
+    QTime getIdlenessACTime();
+    void setIdlenessACTime(QTime idlenessTime);
+
+    int getIdlenessBatteryAction();
+    void setIdlenessBatteryAction(int idlenessAction);
+
+    QTime getIdlenessBatteryTime();
+    void setIdlenessBatteryTime(QTime idlenessTime);
+
     bool isIdlenessBacklightWatcherEnabled();
     void setIdlenessBacklightWatcherEnabled(bool idlenessBacklightWatcherEnabled);
 
@@ -103,6 +110,9 @@ public:
     bool isIdlenessBacklightOnBatteryDischargingEnabled();
     void setIdlenessBacklightOnBatteryDischargingEnabled(bool enabled);
 
+    bool isDisableIdlenessWhenFullscreenEnabled();
+    void setDisableIdlenessWhenFullscreen(bool enabled);
+
     int getPowerKeyAction();
     void setPowerKeyAction(int action);
     
