@@ -44,13 +44,13 @@ BatteryInfoFrame::BatteryInfoFrame(Solid::Battery *battery) :
     mUi->typeValue->setText(BatteryHelper::typeToString(mBattery->type()));
     mUi->technologyValue->setText(BatteryHelper::technologyToString(mBattery->technology()));
 
-    QString vendor = QString::fromLatin1("%1 %2").arg(battery->recallVendor()).arg(battery->serial());
+    QString vendor = QString::fromLatin1("%1 %2").arg( battery->recallVendor() , battery->serial() );
     if (vendor.trimmed().isEmpty())
         vendor = QSL("Unknown");
     mUi->vendorValue->setText(vendor);
 
-    connect(mBattery, SIGNAL(energyChanged(double, const QString)), this, SLOT(onBatteryChanged()));
-    connect(mBattery, SIGNAL(chargeStateChanged(int, const QString)), this, SLOT(onBatteryChanged()));
+    connect(mBattery, &Solid::Battery::energyChanged, this, &BatteryInfoFrame::onBatteryChanged);
+    connect(mBattery, &Solid::Battery::chargeStateChanged, this, &BatteryInfoFrame::onBatteryChanged);
     onBatteryChanged();
 }
 
