@@ -39,14 +39,15 @@ public:
 
 private Q_SLOTS:
     void setup();
-    void timeoutReached(int identifier);
+    void timeoutReached(int identifier,int msec);
     void resumingFromIdle();
     void onBatteryChanged(int newState, const QString &udi = QString());
     void onSettingsChanged();
 
 private:
     PowerManagementSettings mPSettings;
-    int mIdleWatcher;
+    int mIdleACWatcher;
+    int mIdleBatteryWatcher;
     int mIdleBacklightWatcher;
     LXQt::Backlight *mBacklight;
     int mBacklightActualValue;
