@@ -41,8 +41,8 @@ class LidWatcher : public Watcher
 {
     Q_OBJECT
 public:
-    explicit LidWatcher(QObject *parent = 0);
-    virtual ~LidWatcher();
+    explicit LidWatcher(QObject *parent = nullptr);
+    ~LidWatcher() override;
 
 private slots:
     void lidChanged(bool closed);
