@@ -16,7 +16,7 @@
     <message>
         <location filename="../batteryhelper.cpp" line="46"/>
         <source>Fully charged</source>
-        <translation>Teletöltve</translation>
+        <translation>Teljesen feltöltve</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="49"/>
@@ -36,7 +36,7 @@
     <message>
         <location filename="../batteryhelper.cpp" line="62"/>
         <source>Lithium iron phosphate</source>
-        <translation>Lítium vasfoszfát</translation>
+        <translation>Lítium vas-foszfát</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="64"/>
@@ -61,52 +61,52 @@
     <message>
         <location filename="../batteryhelper.cpp" line="80"/>
         <source>Personal Digital Assistant&apos;s battery</source>
-        <translation>PDA táp</translation>
+        <translation>PDA akkumulátor</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="82"/>
         <source>Uninterruptible Power Supply&apos;s battery</source>
-        <translation>Folytonos táp</translation>
+        <translation>Szünetmentes tápegység akkumulátora</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="84"/>
         <source>Primary battery</source>
-        <translation>Elsődleges táp</translation>
+        <translation>Elsődleges akkumulátor</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="86"/>
         <source>Mouse battery</source>
-        <translation>Egér táp</translation>
+        <translation>Egér akkumulátor</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="88"/>
         <source>Keyboard battery</source>
-        <translation>Bellentyűzet táp</translation>
+        <translation>Billentyűzet akkumulátor</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="90"/>
         <source>Keyboard and mouse&apos;s battery</source>
-        <translation>Billentyű és egértáp</translation>
+        <translation>Billentyűzet és egérakkumulátor</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="92"/>
         <source>Camera battery</source>
-        <translation>Kamera táp</translation>
+        <translation>Kamera akkumulátor</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="94"/>
         <source>Phone battery</source>
-        <translation>Telefon táp</translation>
+        <translation>Telefon akkumulátor</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="96"/>
         <source>Monitor battery</source>
-        <translation>Monitor táp</translation>
+        <translation>Monitor akkumulátor</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="99"/>
         <source>Unknown battery</source>
-        <translation>Ismeretlen táp</translation>
+        <translation>Ismeretlen akkumulátor</translation>
     </message>
 </context>
 <context>
@@ -114,7 +114,7 @@
     <message>
         <location filename="../batteryinfodialog.ui" line="14"/>
         <source>Dialog</source>
-        <translation>Párbeszéd</translation>
+        <translation>Párbeszédablak</translation>
     </message>
     <message>
         <location filename="../batteryinfodialog.cpp" line="24"/>
@@ -132,7 +132,7 @@
     <message>
         <location filename="../batteryinfoframe.ui" line="53"/>
         <source>Temperature:</source>
-        <translation>Hőfok:</translation>
+        <translation>Hőmérséklet:</translation>
     </message>
     <message>
         <location filename="../batteryinfoframe.ui" line="63"/>
@@ -157,7 +157,7 @@
     <message>
         <location filename="../batteryinfoframe.ui" line="124"/>
         <source>Energy Now:</source>
-        <translation type="unfinished">Mostani kapacitás:</translation>
+        <translation>Jelenlegi kapacitás:</translation>
     </message>
     <message>
         <location filename="../batteryinfoframe.ui" line="141"/>
@@ -190,7 +190,7 @@
     <message>
         <location filename="../batterywatcher.cpp" line="49"/>
         <source>LXQt could not find data about any battery - monitoring disabled</source>
-        <translation>Az LXQt nem ismert fel akkut - figyelés kikapcsolva</translation>
+        <translation>Az LXQt nem talált adatokat egyetlen akkumulátorról sem - figyelés letiltva</translation>
     </message>
     <message>
         <location filename="../batterywatcher.cpp" line="114"/>
@@ -208,14 +208,14 @@
         <location filename="../batterywatcher.cpp" line="129"/>
         <source>Hibernating in %n second(s)</source>
         <translation>
-            <numerusform>Mélykészenlét %n másodperc múlva</numerusform>
+            <numerusform>Hibernálás %n másodperc múlva</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="132"/>
         <source>Shutting down in %n second(s)</source>
         <translation>
-            <numerusform>Kikapcsolás %n másodperc múlva</numerusform>
+            <numerusform>Leállítás %n másodperc múlva</numerusform>
         </translation>
     </message>
 </context>
@@ -248,7 +248,7 @@
         <location filename="../powermanagementd.cpp" line="116"/>
         <source>You are running LXQt Power Management for the first time.
 You can configure it from settings... </source>
-        <translation>Az LXQt energiakezelő első alkalommal fut.
+        <translation>Az LXQt energiakezelő az első alkalommal fut.
 A beállításokban konfigurálható... </translation>
     </message>
     <message>
@@ -260,40 +260,40 @@ A beállításokban konfigurálható... </translation>
 <context>
     <name>TrayIcon</name>
     <message>
-        <location filename="../trayicon.cpp" line="61"/>
+        <location filename="../trayicon.cpp" line="60"/>
         <source>Configure</source>
         <translation>Beállítás</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="63"/>
-        <location filename="../trayicon.cpp" line="94"/>
+        <location filename="../trayicon.cpp" line="62"/>
+        <location filename="../trayicon.cpp" line="93"/>
         <source>About</source>
         <translation>Névjegy</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="65"/>
+        <location filename="../trayicon.cpp" line="64"/>
         <source>Disable icon</source>
-        <translation>Ikon kikapcsolása</translation>
+        <translation>Ikon letiltása</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="95"/>
+        <location filename="../trayicon.cpp" line="94"/>
         <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
-        <translation>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Energiakezelő az LXQt asztali környezethez&lt;/p&gt;&lt;p&gt;  Szerzők:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - és mások a Razor és LXQt csapatból&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;  &lt;b&gt;LXQt energiakezelés&lt;/b&gt;&lt;br/&gt;  - Energiakezelő az LXQt asztali környezethez&lt;/p&gt;&lt;p&gt;  Szerzők:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - és mások a Razor és LXQt csapatból&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="112"/>
+        <source>LXQt Power Management info</source>
+        <translation>LXQt energiakezelő információ</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="113"/>
-        <source>LXQt Power Management info</source>
-        <translation>LXQt Energiakezelő információ</translation>
-    </message>
-    <message>
-        <location filename="../trayicon.cpp" line="114"/>
         <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
-        <translation>Az LXQt energiakezelő tálcaikon (újra)engedélyezhető az &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt; segítségével</translation>
+        <translation>Az LXQt energiakezelő tálcaikon (újra)engedélyezhető az &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;ben</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="116"/>
+        <location filename="../trayicon.cpp" line="115"/>
         <source>Configure now</source>
-        <translation>Beállítás</translation>
+        <translation>Beállítás most</translation>
     </message>
 </context>
 </TS>
